## 业绩预告

接口：forecast，可以通过数据工具调试和查看数据。

描述：获取业绩预告数据

权限：用户需要至少2000积分才可以调取，具体请参阅积分获取办法



提示：当前接口只能按单只股票获取其历史数据，如果需要获取某一季度全部上市公司数据，请使用forecast_vip接口（参数一致），需积攒5000积分。



输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码(二选一) |
| ann_date | str | N | 公告日期 (二选一) |
| start_date | str | N | 公告开始日期 |
| end_date | str | N | 公告结束日期 |
| period | str | N | 报告期(每个季度最后一天的日期，比如20171231表示年报，20170630半年报，20170930三季报) |
| type | str | N | 预告类型(预增/预减/扭亏/首亏/续亏/续盈/略增/略减) |

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| ts_code | str | TS股票代码 |
| ann_date | str | 公告日期 |
| end_date | str | 报告期 |
| type | str | 业绩预告类型(预增/预减/扭亏/首亏/续亏/续盈/略增/略减) |
| p_change_min | float | 预告净利润变动幅度下限（%） |
| p_change_max | float | 预告净利润变动幅度上限（%） |
| net_profit_min | float | 预告净利润下限（万元） |
| net_profit_max | float | 预告净利润上限（万元） |
| last_parent_net | float | 上年同期归属母公司净利润 |
| first_ann_date | str | 首次公告日 |
| summary | str | 业绩预告摘要 |
| change_reason | str | 业绩变动原因 |

接口用法

```python
pro = ts.pro_api()

pro.forecast(ann_date='20190131', fields='ts_code,ann_date,end_date,type,p_change_min,p_change_max,net_profit_min')
```

获取某一季度全部股票数据

```python
df = pro.forecast_vip(period='20181231',fields='ts_code,ann_date,end_date,type,p_change_min,p_change_max,net_profit_min')
```

数据样例

```python
ts_code  ann_date  end_date type  p_change_min  p_change_max  \
0    000005.SZ  20190131  20181231   预增      618.5600      945.1800   
```